@@ -2,7 +2,6 @@ import six
 import os
 import warnings
 import numpy as np
-from datasets import load_dataset, get_dataset_config_names, list_datasets
 from sklearn.feature_extraction import text
 from sklearn import decomposition
 
@@ -13,6 +12,11 @@ try:
 except ModuleNotFoundError:  # ignore missing flair module for now...
     pass
 
+try:
+    from datasets import load_dataset, get_dataset_config_names, list_datasets
+except ModuleNotFoundError:  # this will be triggered if hugging-face libraries aren't installed
+    pass
+
 from .array import is_array, wrangle_array
 from .dataframe import is_dataframe
 from .null import is_null
@@ -120,6 +124,9 @@ def get_text_model(x):
             return eval(f'{parent}.{model_name}')
         except AttributeError:
             return None
+        except NameError:
+            raise ModuleNotFoundError('Hugging-face libraries have not been installed.  To use hugging-face models, please run "pip install --upgrade pydata-wrangler[hf]" to fix.')
+
 
     for p in ['text', 'decomposition', 'embeddings']:
         m = model_lookup(x, p)
@@ -185,6 +192,8 @@ def get_corpus(dataset_name='wikipedia', config_name='20200501.en'):
     except ValueError:
         raise RuntimeError(f'Configuration for {dataset_name} corpus not found: {config_name}. '
                            f'Available configurations: {", ".join(get_dataset_config_names(dataset_name))}')
+    except NameError:
+        raise ModuleNotFoundError('Hugging-face libraries have not been installed.  To use hugging-face corpora, please run "pip install --upgrade pydata-wrangler[hf]" to fix.')
 
     corpus = []
     content_keys = ['text', 'content']
@@ -319,32 +328,32 @@ def apply_text_model(x, text, *args, mode='fit_transform', return_model=False, *
 
         # document-level embeddings-- re-compute by token
         if hasattr(wrapped_text, 'embedding') and len(wrapped_text.embedding) > 0:
-            embeddings = np.empty([len(wrapped_text), len(wrapped_text.embedding)])
-            embeddings[:] = np.nan
+            embedded_text = np.empty([len(wrapped_text), len(wrapped_text.embedding)])
+            embedded_text[:] = np.nan
 
             for i, token in enumerate(wrapped_text):
                 next_wrapped = Sentence(token.text)
                 model.embed(next_wrapped)
                 try:
-                    embeddings[i, :] = next_wrapped.embedding.detach().numpy()
+                    embedded_text[i, :] = next_wrapped.embedding.detach().numpy()
                 except TypeError: # if running on GPU, copy to CPU before converting to an array
-                    embeddings[i, :] = next_wrapped.embedding.cpu().detach().numpy()
+                    embedded_text[i, :] = next_wrapped.embedding.cpu().detach().numpy()
         else:  # token-level embeddings; wrangle into an array
-            embeddings = np.empty([len(wrapped_text), len(wrapped_text[0].embedding)])
-            embeddings[:] = np.nan
+            embedded_text = np.empty([len(wrapped_text), len(wrapped_text[0].embedding)])
+            embedded_text[:] = np.nan
             for i, token in enumerate(wrapped_text):
                 if len(token.embedding) > 0:
                     try:
-                        embeddings[i, :] = token.embedding
+                        embedded_text[i, :] = token.embedding
                     except TypeError:  # if the embeddings were computed on a GPU we need to copy them over to the CPU
-                        embeddings[i, :] = token.embedding.cpu()
+                        embedded_text[i, :] = token.embedding.cpu()
 
         if return_model:
-            return embeddings, {'model': model, 'args': args,
-                                'kwargs': {'embedding_kwargs': embedding_kwargs,
-                                           **kwargs}}
+            return embedded_text, {'model': model, 'args': args,
+                                   'kwargs': {'embedding_kwargs': embedding_kwargs,
+                                              **kwargs}}
         else:
-            return embeddings
+            return embedded_text
     else:                                 # unknown model
         raise RuntimeError('Cannot apply text model: {model}')
 
